==> this.path_0.11.0.tar.gz: this.path/inst/NEWS.Rd <==
\name{NEWS}
\title{\pkg{this.path} News}
\encoding{UTF-8}
\section{CHANGES IN VERSION 0.11.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Added \code{tryCatch2()}, introducing argument \code{else.} similar
            to \code{try except} in \sQuote{Python}.
      \item Added \code{else.} argument to \code{this.path()},
            \code{this.dir()}, \code{shFILE()}, and \code{normalized.shFILE()},
            a function to act on the return value.
    }
  }
}
\section{CHANGES IN VERSION 0.10.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Added \code{asArgs()}, \code{fileArgs()}, and
            \code{withArgs()} to more easily provide arguments to a
            script.
      \item Added \code{from.shell()} to determine if a script was run
            from a shell.
      \item Added \code{this.proj(...)}, similar to
            \code{here::here(...)}, except that \code{this.proj()}
            supports multiple projects in one \R session.
    }
  }
  \subsection{BUG FIXES}{
    \itemize{
      \item \code{this.path::here()} no longer uses \code{dirname()} on
            a UNC path.
    }
  }
}
\section{CHANGES IN VERSION 0.9.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item \code{this.path()} and all its associated functions now
            work in VSCode.
    }
  }
  \subsection{BUG FIXES}{
    \itemize{
      \item when \code{source}-ing a file URL,
            \code{source("file:///path/to/file")}, \code{this.path()}
            no longer attempts to re-open a connection.
    }
  }
}
\section{CHANGES IN VERSION 0.8.0}{
  \subsection{SIGNIFICANT USER-VISIBLE CHANGES}{
    \itemize{
      \item All previously defunct functions were removed entirely.
    }
  }
  \subsection{NEW FEATURES}{
    \itemize{
      \item \code{this.path()}, \code{this.dir()}, \code{shFILE()}, and
            \code{normalized.shFILE()} were given a new argument
            \code{default} that will be evaluated and returned if there
            is no executing script or command line argument
            \option{FILE} was not found.
    }
  }
  \subsection{DEPRECATED AND DEFUNCT}{
    \itemize{
      \item \code{this.path2()}, \code{this.dir2()}, and
            \code{this.dir3()} are deprecated and should be replaced
            with \code{this.path(default = NULL)},
            \code{this.dir(default = NULL)}, and
            \code{this.dir(default = getwd())}, respectively.
    }
  }
  \subsection{BUG FIXES}{
    \itemize{
      \item \code{normalized.shFILE()} no longer sets attribute
            \code{"this.path.from.shell"}, that is now handled by
            \code{this.path()}.
    }
  }
}

==> this.path_1.0.1.tar.gz: this.path/inst/NEWS.Rd <==
\name{NEWS}
\title{\pkg{this.path} News}
\encoding{UTF-8}
\section{CHANGES IN VERSION 1.0.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Added \code{path.join()}, \code{basename2()}, and \code{dirname2()}
            for constructing and manipulating paths to files. These are based
            on \code{file.path()}, \code{basename()}, and \code{dirname()}, but
            behave differently with network shares and a few important edge
            cases.
    }
  }
  \subsection{SIGNIFICANT USER-VISIBLE CHANGES}{
    \itemize{
      \item \code{this.dir()}, \code{here()}, and \code{this.proj()} all use
            \code{path.join()} and \code{dirname2()} instead of
            \code{file.path()} and \code{dirname()}, this may change behaviour
            for some users and cases, but should be an improvement overall.
    }
  }
}
\section{CHANGES IN VERSION 0.11.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Added \code{tryCatch2()}, introducing argument \code{else.} similar
            to \code{try except} in \sQuote{Python}.
      \item Added \code{else.} argument to \code{this.path()},
            \code{this.dir()}, \code{shFILE()}, and \code{normalized.shFILE()},
            a function to act on the return value.
    }
  }
}
\section{CHANGES IN VERSION 0.10.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Added \code{asArgs()}, \code{fileArgs()}, and
            \code{withArgs()} to more easily provide arguments to a
            script.
      \item Added \code{from.shell()} to determine if a script was run
            from a shell.
      \item Added \code{this.proj(...)}, similar to
            \code{here::here(...)}, except that \code{this.proj()}
            supports multiple projects in one \R session.
    }
  }
  \subsection{BUG FIXES}{
    \itemize{
      \item \code{this.path::here()} no longer uses \code{dirname()} on
            a UNC path.
    }
  }
}
\section{CHANGES IN VERSION 0.9.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item \code{this.path()} and all its associated functions now
            work in VSCode.
    }
  }
  \subsection{BUG FIXES}{
    \itemize{
      \item when \code{source}-ing a file URL,
            \code{source("file:///path/to/file")}, \code{this.path()}
            no longer attempts to re-open a connection.
    }
  }
}
\section{CHANGES IN VERSION 0.8.0}{
  \subsection{SIGNIFICANT USER-VISIBLE CHANGES}{
    \itemize{
      \item All previously defunct functions were removed entirely.
    }
  }
  \subsection{NEW FEATURES}{
    \itemize{
      \item \code{this.path()}, \code{this.dir()}, \code{shFILE()}, and
            \code{normalized.shFILE()} were given a new argument
            \code{default} that will be evaluated and returned if there
            is no executing script or command line argument
            \option{FILE} was not found.
    }
  }
  \subsection{DEPRECATED AND DEFUNCT}{
    \itemize{
      \item \code{this.path2()}, \code{this.dir2()}, and
            \code{this.dir3()} are deprecated and should be replaced
            with \code{this.path(default = NULL)},
            \code{this.dir(default = NULL)}, and
            \code{this.dir(default = getwd())}, respectively.
    }
  }
  \subsection{BUG FIXES}{
    \itemize{
      \item \code{normalized.shFILE()} no longer sets attribute
            \code{"this.path.from.shell"}, that is now handled by
            \code{this.path()}.
    }
  }
}
